@@ -1,9 +1,56 @@
 #
+#' Functions to manipulate rows of a worksheet.
+#'
+#' \code{removeRow} is just a convenience wrapper to remove the rows from the
+#' sheet (before saving).  Internally it calls \code{lapply}.
+#'
+#' @param sheet a worksheet object as returned by \code{createSheet} or by
+#' subsetting \code{getSheets}.
+#' @param rowIndex a numeric vector specifying the index of rows to create.
+#' For \code{getRows}, a \code{NULL} value will return all non empty rows.
+#' @param rows a list of \code{Row} objects.
+#' @param inPoints a numeric value to specify the height of the row in points.
+#' @param multiplier a numeric value to specify the multiple of default row
+#' height in points.  If this value is set, it takes precedence over the
+#' \code{inPoints} argument.
+#' @return For \code{getRows} a list of java object references each pointing to
+#' a row.  The list is named with the row number.
+#' @author Adrian Dragulescu
+#' @seealso To extract the cells from a given row, see \code{\link{Cell}}.
+#' @examples
+#'
+#'
+#' file <- system.file("tests", "test_import.xlsx", package = "xlsx")
+#'
+#' wb <- loadWorkbook(file)
+#' sheets <- getSheets(wb)
+#'
+#' sheet <- sheets[[2]]
+#' rows  <- getRows(sheet)  # get all the rows
+#'
+#' # see all the available java methods that you can call
+#' rJava::.jmethods(rows[[1]])
+#'
+#' # for example
+#' rows[[1]]$getRowNum()   # zero based index in Java
+#'
+#' removeRow(sheet, rows)  # remove them all
+#'
+#' # create some row
+#' rows  <- createRow(sheet, rowIndex=1:5)
+#' setRowHeight( rows, multiplier=3)  # 3 times bigger rows than the default
+#'
+#'
+#'
+#' @name Row
+NULL
 
 
 ######################################################################
 # Return a list of row objects.
 #
+#' @export
+#' @rdname Row
 createRow <- function(sheet, rowIndex=1:5)
 {
   rows <- vector("list", length(rowIndex))
@@ -11,16 +58,18 @@ createRow <- function(sheet, rowIndex=1:5)
   for (ir in seq_along(rowIndex))
     rows[[ir]] <- .jcall(sheet, "Lorg/apache/poi/ss/usermodel/Row;",
       "createRow", as.integer(rowIndex[ir]-1)) # in java the index starts from 0!
-  
+
   rows
 }
 
 
 ######################################################################
 # Return a list of all row objects in a sheet.
-# You can specify which rows you want to return by provinding a vector of 
+# You can specify which rows you want to return by provinding a vector of
 # rowIndices with rowInd.
 #
+#' @export
+#' @rdname Row
 getRows <- function(sheet, rowIndex=NULL)
 {
   noRows <- sheet$getLastRowNum()+1
@@ -43,7 +92,7 @@ getRows <- function(sheet, rowIndex=NULL)
   names(rows) <- namesRow   # need this if rows are ragged
 
   rows <- rows[!is.na(namesRow)]   # skip the empty rows
-  
+
   rows
 }
 
@@ -51,6 +100,8 @@ getRows <- function(sheet, rowIndex=NULL)
 ######################################################################
 # remove rows
 #
+#' @export
+#' @rdname Row
 removeRow <- function(sheet, rows=NULL)
 {
   if (is.null(rows))
@@ -65,6 +116,8 @@ removeRow <- function(sheet, rows=NULL)
 ######################################################################
 # set the Row height
 #
+#' @export
+#' @rdname Row
 setRowHeight <- function(rows, inPoints, multiplier=NULL)
 {
   if ( !is.null(multiplier) ) {
@@ -73,7 +126,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
   }
 
   lapply(rows, function(row) {
-    row$setHeightInPoints( .jfloat(inPoints) )  
+    row$setHeightInPoints( .jfloat(inPoints) )
   })
 
   invisible()
@@ -102,7 +155,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##   prototype = prototype(
 ##     INITIAL_CAPACITY = as.integer(3),
 ##     ref = .jnull()
-##     ) 
+##     )
 ## )
 
 
@@ -113,7 +166,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ## setMethod("show", "WorksheetEntry",
 ##   function(object){
 ##     callNextMethod(object)
-##     cat("\n@nrow =", object@nrow, 
+##     cat("\n@nrow =", object@nrow,
 ##         "\n@ncol =", object@ncol)
 ##   })
 
@@ -129,7 +182,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##   id <- .getUniqueId(xls@id)[[1]]
 ##   worksheetId <- paste("http://spreadsheets.google.com/feeds/spreadsheets/",
 ##                        id, sep="")
-   
+
 ##   msg <- xls@con@ref$getWorksheetEntries(worksheetId)
 
 ##   msg <- strsplit(msg, "\n")[[1]]      # split by worksheets
@@ -143,7 +196,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##   msg <- lapply(msg, as.list)
 ##   msg <- lapply(msg, function(x, slotNames){names(x) <- slotNames; x},
 ##                 slotNames)
-  
+
 ##   msg <- lapply(msg,
 ##     function(x, slotNames){
 ##       x$canEdit <- as.logical(toupper(x$canEdit))
@@ -152,14 +205,14 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##       x$published <- as.POSIXct(x$published, "%Y-%m-%dT%H:%M:%OSZ", tz="")
 ##       x
 ##     }, slotNames)
- 
+
 ##   wks <- vector("list", length(msg))
 ##   for (w in 1:length(wks)){
 ##     listFields <- msg[[w]]
 ##     listFields$con <- xls@con
 ##     wks[[w]] <- new("WorksheetEntry", listFields)  # call the constructor
 ##   }
-  
+
 ##   wks
 ## }
 
@@ -194,7 +247,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ## {
 ##   id <- gsub("worksheets", "list", wks@id)
 ##   worksheetId <- paste(id, "/private/full", sep="")
-   
+
 ##   msg <- wks@con@ref$getListEntries(worksheetId)
 
 ##   if (wks@con@ref$getMsg() != "")
@@ -211,14 +264,14 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##   msg <- lapply(msg, as.list)
 ##   msg <- lapply(msg, function(x, slotNames){names(x) <- slotNames; x},
 ##                 slotNames)
-  
+
 ##   msg <- lapply(msg,
 ##     function(x, slotNames){
 ##       x$canEdit <- as.logical(toupper(x$canEdit))
 ##       x$published <- as.POSIXct(x$published, "%Y-%m-%dT%H:%M:%OSZ", tz="")
 ##       x
 ##     }, slotNames)
- 
+
 ##   entries <- vector("list", length(msg))
 ##   for (e in 1:length(entries)){
 ##     listFields       <- msg[[e]]
@@ -227,7 +280,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##     entries[[e]] <- new("ListEntry", listFields)  # call the constructor
 ##   }
 ##   names(entries) <- sapply(entries, slot, "rowId")
-  
+
 ##   entries
 ## }
 
@@ -252,7 +305,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##     values <- matrix(msg[seq.int(2,N,2)], ncol=N/2, byrow=TRUE)
 ##     colnames(values) <- msg[seq.int(1,N,2)]
 ##     rownames(values) <- obj@rowId
-    
+
 ##     values
 ##   }
 ## )
@@ -289,7 +342,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ## {
 ##   if (length(contentList)==1 & !is.list(contentList[1]))
 ##     contentList <- list(contentList) # give the user a break
-  
+
 ##   if (length(listEntries) != length(contentList))
 ##     stop("Non-equal length for the two arguments!")
 
@@ -300,7 +353,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##     paste(substr(id, 1, ind[length(ind)]), "private/full/",
 ##           substr(id, ind[length(ind)]+1, nchar(id)), sep="")}, id, ind)
 ##   ids <- paste(id, sep="", collapse="\n")
-  
+
 ##   # make content string. tag,values separated by \t, listEntries
 ##   # separated by \t.
 ##   content <- sapply(contentList, function(x){
@@ -335,7 +388,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 
 ## ##########################################################################
 ## # create an empty worksheet.  Call it new instead of add for consistency
-## # with other objects. 
+## # with other objects.
 ## addWorksheet <- function(xls, title, nrow=100, ncol=20)
 ## {
 ##   key <- gsub("spreadsheet%3A(.*)", "\\1", xls@key)
@@ -355,7 +408,7 @@ setRowHeight <- function(rows, inPoints, multiplier=NULL)
 ##   id  <- paste(substr(id, 1, ind[length(ind)]), "private/full/",
 ##                substr(id, ind[length(ind)]+1, nchar(id)), sep="")
 ##   wks@con@ref$deleteWorksheet(id)
-   
+
 ##   invisible(as.logical(wks@con@ref$getMsg()))
 ## }
 
