@@ -3,7 +3,7 @@
 # .Rcolor2XLcolor
 # .splitBlocks
 # .hssfcolor
-# .xssfcolor  
+# .xssfcolor
 
 
 
@@ -23,13 +23,13 @@
       FALSE
     } else {
       dateUtil$isCellDateFormatted(x)
-    } 
+    }
   }, cells, cellType)
 
   guessedColClasses <- ifelse(cellType==1,"numeric", "character")
 
   guessedColClasses[isDateTime] <- "POSIXct"
-  
+
   guessedColClasses
 }
 
@@ -39,20 +39,23 @@
 .onLoad <- function(libname, pkgname)
 {
   rJava::.jpackage("xlsxjars")
-  rJava::.jpackage(pkgname)  # needed to load RInterface.java
-  
+  rJava::.jpackage(pkgname, lib.loc = libname)  # needed to load RInterface.java
+
   # what's your java  version?  Need > 1.5.0.
   jversion <- .jcall('java.lang.System','S','getProperty','java.version')
-  if (jversion < "1.5.0")
+
+  parse_version <- regexpr("[0-9]+\\.[0-9]+\\.[0-9]+", jversion)
+  clean_version <- substr(jversion, parse_version, attr(parse_version, "match.length"))
+  if (utils::compareVersion(clean_version,"1.5.0") < 0)
     stop(paste("Your java version is ", jversion,
                  ".  Need 1.5.0 or higher.", sep=""))
-  
-  wb <- createWorkbook()   # load/initialize jars here as it takes 
+
+  wb <- createWorkbook()   # load/initialize jars here as it takes
   rm(wb)                   # a few seconds ...
-  
+
   options(xlsx.date.format = "m/d/yyyy")   # e.g. 3/18/2013
   options(xlsx.datetime.format = "m/d/yyyy h:mm:ss")  # e.g. 3/18/2013 05:25:51
-  
+
 }
 
 ####################################################################
@@ -63,9 +66,9 @@
 {
   if ( isXSSF ) {
     sapply( rcolor, .xssfcolor )
-  } else {                     
-    sapply( rcolor, .hssfcolor ) 
-  }    
+  } else {
+    sapply( rcolor, .hssfcolor )
+  }
 }
 
 
@@ -79,7 +82,7 @@
   blocks <- list(x[1])
   if (length(x)==1)
     return(blocks)
-  
+
   k <- 1
   for (i in 2:length(x)) {
     if (x[i]==(x[i-1]+1)) {
@@ -98,7 +101,7 @@
 # Take an R color and return an HSSFColor object
 # @param Rcolor is a string
 #   NOTE: Only a limited set of colors are supported.  See the java API.
-# 
+#
 .hssfcolor <- function(Rcolor)
 {
   .jshort(INDEXED_COLORS_[toupper( Rcolor )])
@@ -110,32 +113,46 @@
 # @param Rcolor is a string returned from "colors()" or a hex string
 #   starting with #, e.g. "#FF0000" is red.
 #
+#' @importFrom grDevices col2rgb
 .xssfcolor <- function(Rcolor)
 {
   if (grepl("^#", Rcolor)) {
     rgb <- c(strtoi(substring(Rcolor, 2, 3), base=16L),
              strtoi(substring(Rcolor, 4, 5), base=16L),
-             strtoi(substring(Rcolor, 6, 7), base=16L)) 
-  } else {     
+             strtoi(substring(Rcolor, 6, 7), base=16L))
+  } else {
     rgb <- as.integer(col2rgb(Rcolor))
   }
   jcol <- .jnew("java.awt.Color", rgb[1], rgb[2], rgb[3])
-  
+
   .jnew("org.apache.poi.xssf.usermodel.XSSFColor", jcol)
 }
 
 
+#' @title Constants used in the project.
+#'
+#' @description Document some Apache POI constants used in the project.
+#'
+#' @return A named vector.
+#' @author Adrian Dragulescu
+#' @seealso \code{\link{CellStyle}} for using the \code{POI_constants}.
+#' @name POI_constants
+NULL
 
-
+  #' @rdname POI_constants
+  #' @export
   HALIGN_STYLES_ <- c(2,6,4,0,5,1,3)
   names(HALIGN_STYLES_) <- c('ALIGN_CENTER' ,'ALIGN_CENTER_SELECTION'
     ,'ALIGN_FILL' ,'ALIGN_GENERAL' ,'ALIGN_JUSTIFY' ,'ALIGN_LEFT'
     ,'ALIGN_RIGHT')
 
+  #' @rdname POI_constants
+  #' @export
   VALIGN_STYLES_<- c(2,1,3,0)
   names(VALIGN_STYLES_) <- c('VERTICAL_BOTTOM' ,'VERTICAL_CENTER',
                              'VERTICAL_JUSTIFY' ,'VERTICAL_TOP')
-              
+  #' @rdname POI_constants
+  #' @export
   BORDER_STYLES_ <- c(9,11,3,7,6,4,2,10,12,8,0,13,5,1)
   names(BORDER_STYLES_) <- c("BORDER_DASH_DOT", "BORDER_DASH_DOT_DOT",
     "BORDER_DASHED", "BORDER_DOTTED", "BORDER_DOUBLE", "BORDER_HAIR",
@@ -144,6 +161,8 @@
     "BORDER_NONE", "BORDER_SLANTED_DASH_DOT", "BORDER_THICK",
     "BORDER_THIN")
 
+  #' @rdname POI_constants
+  #' @export
   FILL_STYLES_<- c(3,9,10,16,2,18,17,0,1,4,15,7,8,5,6,13,14,11,12)
   names(FILL_STYLES_) <- c('ALT_BARS', 'BIG_SPOTS','BRICKS' ,'DIAMONDS'
     ,'FINE_DOTS' ,'LEAST_DOTS' ,'LESS_DOTS' ,'NO_FILL'
@@ -152,10 +171,14 @@
     ,'THICK_VERT_BANDS' ,'THIN_BACKWARD_DIAG' ,'THIN_FORWARD_DIAG'
     ,'THIN_HORZ_BANDS' ,'THIN_VERT_BANDS')
 
-  # from org.apache.poi.ss.usermodel.CellStyle  
+  # from org.apache.poi.ss.usermodel.CellStyle
+  #' @rdname POI_constants
+  #' @export
   CELL_STYLES_ <- c(HALIGN_STYLES_, VALIGN_STYLES_,
      BORDER_STYLES_, FILL_STYLES_)
 
+  #' @rdname POI_constants
+  #' @export
   INDEXED_COLORS_ <- c(8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,
     25,26,28,29,30,31,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,
     56,57,58,59,60,61,62,63,64)
@@ -170,5 +193,3 @@
     ,'GREY_40_PERCENT' ,'DARK_TEAL' ,'SEA_GREEN' ,'DARK_GREEN'
     ,'OLIVE_GREEN' ,'BROWN' ,'PLUM' ,'INDIGO' ,'GREY_80_PERCENT'
     ,'AUTOMATIC')
-  
-                   
